@@ -1,5 +1,5 @@
-#ifndef __8MT18_13
-#define __8MT18_13
+#ifndef __8MT175_100
+#define __8MT175_100
 
 #include <string.h>
 
@@ -10,18 +10,18 @@
 #endif
 
 
-#define 8MT18_13_BUILDER_VERSION_MAJOR  0
-#define 8MT18_13_BUILDER_VERSION_MINOR  9
-#define 8MT18_13_BUILDER_VERSION_BUGFIX 16
-#define 8MT18_13_BUILDER_VERSION_SUFFIX ""
-#define 8MT18_13_BUILDER_VERSION        "0.9.16"
+#define 8MT175_100_BUILDER_VERSION_MAJOR  0
+#define 8MT175_100_BUILDER_VERSION_MINOR  9
+#define 8MT175_100_BUILDER_VERSION_BUGFIX 16
+#define 8MT175_100_BUILDER_VERSION_SUFFIX ""
+#define 8MT175_100_BUILDER_VERSION        "0.9.16"
 
 
 #if defined(_MSC_VER)
 #define inline __inline
 #endif
 
-static inline result_t set_profile_8MT18_13(device_t id)
+static inline result_t set_profile_8MT175_100(device_t id)
 {
   result_t worst_result = result_ok;
   result_t result = result_ok;
@@ -48,8 +48,8 @@ static inline result_t set_profile_8MT18_13(device_t id)
   home_settings.uFastHome = 0;
   home_settings.SlowHome = 500;
   home_settings.uSlowHome = 0;
-  home_settings.HomeDelta = 500;
-  home_settings.uHomeDelta = 0;
+  home_settings.HomeDelta = 626;
+  home_settings.uHomeDelta = 200;
   home_settings.HomeFlags = HOME_USE_FAST | HOME_STOP_SECOND_REV | HOME_STOP_FIRST_BITS | HOME_DIR_SECOND;
   result = set_home_settings(id, &home_settings);
 
@@ -63,11 +63,11 @@ static inline result_t set_profile_8MT18_13(device_t id)
 
   move_settings_t move_settings;
   memset((void*)&move_settings, 0, sizeof(move_settings_t));
-  move_settings.Speed = 457;
+  move_settings.Speed = 1000;
   move_settings.uSpeed = 0;
   move_settings.Accel = 2000;
   move_settings.Decel = 4000;
-  move_settings.AntiplaySpeed = 457;
+  move_settings.AntiplaySpeed = 1000;
   move_settings.uAntiplaySpeed = 0;
   move_settings.MoveFlags = 0;
   result = set_move_settings(id, &move_settings);
@@ -82,14 +82,14 @@ static inline result_t set_profile_8MT18_13(device_t id)
 
   engine_settings_t engine_settings;
   memset((void*)&engine_settings, 0, sizeof(engine_settings_t));
-  engine_settings.NomVoltage = 300;
-  engine_settings.NomCurrent = 180;
-  engine_settings.NomSpeed = 914;
+  engine_settings.NomVoltage = 1;
+  engine_settings.NomCurrent = 1200;
+  engine_settings.NomSpeed = 4000;
   engine_settings.uNomSpeed = 0;
-  engine_settings.EngineFlags = ENGINE_LIMIT_RPM | ENGINE_ACCEL_ON | ENGINE_CURRENT_AS_RMS | ENGINE_REVERSE;
-  engine_settings.Antiplay = 169;
+  engine_settings.EngineFlags = ENGINE_LIMIT_RPM | ENGINE_ACCEL_ON | ENGINE_REVERSE;
+  engine_settings.Antiplay = 575;
   engine_settings.MicrostepMode = MICROSTEP_MODE_FRAC_256;
-  engine_settings.StepsPerRev = 20;
+  engine_settings.StepsPerRev = 200;
   result = set_engine_settings(id, &engine_settings);
 
   if (result != result_ok)
@@ -120,7 +120,7 @@ static inline result_t set_profile_8MT18_13(device_t id)
   power_settings.CurrReductDelay = 1000;
   power_settings.PowerOffDelay = 60;
   power_settings.CurrentSetTime = 300;
-  power_settings.PowerFlags = POWER_SMOOTH_CURRENT | POWER_REDUCT_ENABLED;
+  power_settings.PowerFlags = POWER_SMOOTH_CURRENT | POWER_OFF_ENABLED | POWER_REDUCT_ENABLED;
   result = set_power_settings(id, &power_settings);
 
   if (result != result_ok)
@@ -155,9 +155,9 @@ static inline result_t set_profile_8MT18_13(device_t id)
   memset((void*)&edges_settings, 0, sizeof(edges_settings_t));
   edges_settings.BorderFlags = BORDER_STOP_RIGHT | BORDER_STOP_LEFT;
   edges_settings.EnderFlags = ENDER_SW2_ACTIVE_LOW | ENDER_SW1_ACTIVE_LOW | ENDER_SWAP;
-  edges_settings.LeftBorder = -203;
+  edges_settings.LeftBorder = 374;
   edges_settings.uLeftBorder = 0;
-  edges_settings.RightBorder = 11089;
+  edges_settings.RightBorder = 38374;
   edges_settings.uRightBorder = 0;
   result = set_edges_settings(id, &edges_settings);
 
@@ -255,8 +255,8 @@ static inline result_t set_profile_8MT18_13(device_t id)
 
   control_settings_t control_settings;
   memset((void*)&control_settings, 0, sizeof(control_settings_t));
-  control_settings.MaxSpeed[0] = 45;
-  control_settings.MaxSpeed[1] = 457;
+  control_settings.MaxSpeed[0] = 100;
+  control_settings.MaxSpeed[1] = 1000;
   control_settings.MaxSpeed[2] = 0;
   control_settings.MaxSpeed[3] = 0;
   control_settings.MaxSpeed[4] = 0;
@@ -413,7 +413,7 @@ static inline result_t set_profile_8MT18_13(device_t id)
   memset((void*)&stage_information, 0, sizeof(stage_information_t));
   const int8_t stage_information_Manufacturer_temp[16] = {0, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(stage_information.Manufacturer, stage_information_Manufacturer_temp, sizeof(int8_t) * 16);
-  const int8_t stage_information_PartNumber_temp[24] = {56, 77, 84, 49, 56, 45, 49, 51, 0, 48, 88, 89, 90, 0, 89, 90, 0, 0, 0, 0, 0, 69, 65, 83};
+  const int8_t stage_information_PartNumber_temp[24] = {56, 77, 84, 49, 55, 53, 45, 49, 48, 48, 0, 77, 69, 110, 49, 0, 0, 51, 0, 0, 0, 69, 65, 83};
   memcpy(stage_information.PartNumber, stage_information_PartNumber_temp, sizeof(int8_t) * 24);
   result = set_stage_information(id, &stage_information);
 
@@ -427,16 +427,16 @@ static inline result_t set_profile_8MT18_13(device_t id)
 
   stage_settings_t stage_settings;
   memset((void*)&stage_settings, 0, sizeof(stage_settings_t));
-  stage_settings.LeadScrewPitch = 0.3499999940395355;
+  stage_settings.LeadScrewPitch = 0.5;
   const int8_t stage_settings_Units_temp[8] = {0, 109, 0, 114, 101, 101, 0, 0};
   memcpy(stage_settings.Units, stage_settings_Units_temp, sizeof(int8_t) * 8);
-  stage_settings.MaxSpeed = 1;
-  stage_settings.TravelRange = 13;
+  stage_settings.MaxSpeed = 10;
+  stage_settings.TravelRange = 100;
   stage_settings.SupplyVoltageMin = 0;
   stage_settings.SupplyVoltageMax = 0;
   stage_settings.MaxCurrentConsumption = 0;
-  stage_settings.HorizontalLoadCapacity = 0.5;
-  stage_settings.VerticalLoadCapacity = 0.25;
+  stage_settings.HorizontalLoadCapacity = 0;
+  stage_settings.VerticalLoadCapacity = 0;
   result = set_stage_settings(id, &stage_settings);
 
   if (result != result_ok)
@@ -483,7 +483,7 @@ static inline result_t set_profile_8MT18_13(device_t id)
   motor_settings.SpeedConstant = 0;
   motor_settings.SpeedTorqueGradient = 0;
   motor_settings.MechanicalTimeConstant = 0;
-  motor_settings.MaxSpeed = 2000;
+  motor_settings.MaxSpeed = 5000;
   motor_settings.MaxCurrent = 0;
   motor_settings.MaxCurrentTime = 0;
   motor_settings.NoLoadCurrent = 0;
@@ -569,7 +569,7 @@ static inline result_t set_profile_8MT18_13(device_t id)
   memset((void*)&gear_information, 0, sizeof(gear_information_t));
   const int8_t gear_information_Manufacturer_temp[16] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(gear_information.Manufacturer, gear_information_Manufacturer_temp, sizeof(int8_t) * 16);
-  const int8_t gear_information_PartNumber_temp[24] = {49, 48, 47, 49, 32, 49, 54, 58, 49, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+  const int8_t gear_information_PartNumber_temp[24] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(gear_information.PartNumber, gear_information_PartNumber_temp, sizeof(int8_t) * 24);
   result = set_gear_information(id, &gear_information);
 
@@ -583,7 +583,7 @@ static inline result_t set_profile_8MT18_13(device_t id)
 
   gear_settings_t gear_settings;
   memset((void*)&gear_settings, 0, sizeof(gear_settings_t));
-  gear_settings.ReductionIn = 16;
+  gear_settings.ReductionIn = 1;
   gear_settings.ReductionOut = 1;
   gear_settings.RatedInputTorque = 0;
   gear_settings.RatedInputSpeed = 0;
