@@ -14,38 +14,29 @@
 #include "util.h"
 #include "metadata.h"
 #include "platform.h"
-
 #include "protosup.h"
 #include "wrapper.h"
 
+
 /*
  * Serial port and pipe support
  */
 
-result_t open_port_serial(device_metadata_t *metadata, const char* name)
+result_t open_port_serial(device_metadata_t* metadata, const char* name)
 {
-	HANDLE hDevice;
 	DCB dcb;
 	COMMTIMEOUTS ctm;
-
-	hDevice = CreateFileA( name,
-				GENERIC_READ | GENERIC_WRITE,
-				0,
-				NULL,
-				OPEN_EXISTING,
-				0,
-				0);
-	if (hDevice == INVALID_HANDLE_VALUE)
-	{
-		log_system_error( L"can't open device %hs due to: ", name );
+	HANDLE device = CreateFileA(name, GENERIC_READ | GENERIC_WRITE, 0, NULL, OPEN_EXISTING, 0, 0);
+	if (device == INVALID_HANDLE_VALUE) {
+		log_system_error(L"Failed to open port '%hs' due to: ", name);
 		return result_error;
 	}
 
-	if (!GetCommState( hDevice, &dcb ))
-	{
-		if (!CloseHandle( hDevice ))
-			log_system_error( L"error closing port: " );
-		log_system_error( L"can't get comm state due to: " );
+	if (!GetCommState(device, &dcb)) {
+		log_system_error(L"Failed to get current control settings for port '%hs': ", name);
+		if (!CloseHandle(device))
+			log_system_error(L"Failed to close port '%hs': ", name);
+
 		return result_error;
 	}
 
@@ -65,11 +56,11 @@ result_t open_port_serial(device_metadata_t *metadata, const char* name)
 	dcb.ByteSize = 8;
 	dcb.StopBits = 2;
 
-	if (!SetCommState( hDevice, &dcb ))
-	{
-		if (!CloseHandle( hDevice ))
-			log_system_error( L"error closing port: " );
-		log_system_error( L"can't get comm state due to: " );
+	if (!SetCommState(device, &dcb)) {
+		log_system_error(L"Failed to set control settings for port '%hs': ", name);
+		if (!CloseHandle(device))
+			log_system_error(L"Failed to close port '%hs': ", name);
+
 		return result_error;
 	}
 
@@ -79,59 +70,60 @@ result_t open_port_serial(device_metadata_t *metadata, const char* name)
 	ctm.WriteTotalTimeoutConstant = 0;
 	ctm.WriteTotalTimeoutMultiplier = metadata->port_timeout;
 
-	if (!SetCommTimeouts( hDevice, &ctm ))
-	{
-		if (!CloseHandle( hDevice ))
-			log_system_error( L"error closing port: " );
-		log_system_error( L"can't get comm state due to: " );
+	if (!SetCommTimeouts(device, &ctm)) {
+		log_system_error(L"Failed to set timeout parameters for port '%hs': ", name);
+		if (!CloseHandle(device))
+			log_system_error(L"Failed to close port '%hs': ", name);
+
 		return result_error;
 	}
 
-	/* save metadata */
-	metadata->handle = hDevice;
+	// Save metadata
+	metadata->handle = device;
 	metadata->type = dtSerial;
 
 	return result_ok;
 }
 
-int close_port_serial (device_metadata_t *metadata)
+int close_port_serial(device_metadata_t* metadata)
 {
-	if (CloseHandle( metadata->handle ) == -1)
-	{
-		log_system_error( L"error closing port: " );
+	if (!CloseHandle(metadata->handle)) {
+		log_system_error(L"Failed to close device port: ");
 		return result_serial_error;
 	}
+
 	return result_serial_ok;
 }
 
-int flush_port_serial (device_metadata_t *metadata)
+int flush_port_serial(device_metadata_t* metadata)
 {
-	if (!PurgeComm( metadata->handle, PURGE_RXCLEAR|PURGE_TXCLEAR ))
+	if (!PurgeComm(metadata->handle, PURGE_RXCLEAR | PURGE_TXCLEAR)) {
+		log_system_error(L"Command flush port failed: ");
 		return result_serial_error;
+	}
 
 	return result_serial_ok;
 }
 
-ssize_t read_port_serial (device_metadata_t *metadata, void *buf, size_t amount)
+ssize_t read_port_serial(device_metadata_t* metadata, void* buf, size_t amount)
 {
 	DWORD read_bytes;
-	if (TRUE == ReadFile( metadata->handle, buf, (DWORD)amount, &read_bytes, NULL ))
+	if (TRUE == ReadFile(metadata->handle, buf, (DWORD)amount, &read_bytes, NULL))
 		return (ssize_t)read_bytes;
-	else
-		return 0;
+	
+	return 0;
 }
 
-ssize_t write_port_serial (device_metadata_t *metadata, const void *buf, size_t amount)
+ssize_t write_port_serial(device_metadata_t* metadata, const void* buf, size_t amount)
 {
-	DWORD writ_bytes;
-	if (TRUE == WriteFile( metadata->handle, buf, (DWORD)amount, &writ_bytes, NULL ))
-		return (ssize_t)writ_bytes;
-	else
-		return 0;
+	DWORD write_bytes;
+	if (TRUE == WriteFile(metadata->handle, buf, (DWORD)amount, &write_bytes, NULL))
+		return (ssize_t)write_bytes;
+	
+	return 0;
 }
 
 
-
 /*
  * Threading support
  */
@@ -143,180 +135,135 @@ typedef struct fork_join_carry_t
 	void* arg;
 } fork_join_carry_t;
 
-/* win32 wrapper thread function */
-unsigned int __stdcall check_thread_wrapper_win32 (void *arg)
+/* Win32 wrapper thread function */
+unsigned int __stdcall check_thread_wrapper_win32(void* arg)
 {
 	fork_join_carry_t* carry = (fork_join_carry_t*)arg;
-	carry->function( carry->arg );
+	carry->function(carry->arg);
 	return 0;
 }
 
-/* win32 implementation of fork/join */
-result_t fork_join (fork_join_thread_function_t function, int count, void* args, size_t arg_element_size)
+/* Win32 implementation of fork/join */
+result_t fork_join(fork_join_thread_function_t function, int count, void* args, size_t arg_element_size)
 {
 	result_t result = result_ok;
-	HANDLE* tids;
+	fork_join_carry_t* carry = (fork_join_carry_t*)malloc(count * sizeof(fork_join_carry_t));
+	HANDLE* handles = (HANDLE*)malloc(count * sizeof(HANDLE));
+
+	/* Launch and join */
 	int i;
-	fork_join_carry_t* carry;
-
-	tids = (HANDLE*)malloc( count*sizeof(HANDLE) );
-	carry = (fork_join_carry_t*)malloc( count*sizeof(fork_join_carry_t) );
-
-	/* launch and join */
-	for (i = 0; i < count; ++i)
-	{
+	for (i = 0; i < count; ++i) {
 		carry[i].function = function;
-		carry[i].arg = (byte*)args + i*arg_element_size;
-		tids[i] = (HANDLE)_beginthreadex( NULL, 0, check_thread_wrapper_win32, &carry[i], 0, NULL );
-		if (tids[i] == 0)
-		{
+		carry[i].arg = (byte*)args + i * arg_element_size;
+		handles[i] = (HANDLE)_beginthreadex(NULL, 0, check_thread_wrapper_win32, &carry[i], 0, NULL);
+		if (handles[i] == 0) {
 			result = result_error;
-			log_system_error( L"Failed to create a crt thread due to: " );
+			log_system_error(L"Failed to create a thread: ");
 		}
 	}
+
 	/* Join threads or say there are no devices at all */
-	switch (WaitForMultipleObjects( count, tids, TRUE, INFINITE ))
-	{
-		case WAIT_OBJECT_0:
-			break;
-		case WAIT_FAILED:
-			log_system_error( L"Failed to wait for threads termination due to: " );
-			result = result_error;
-			break;
-		default:
-			log_error( L"Failed to wait for threads termination due to strange reason" );
-			result = result_error;
+	switch (WaitForMultipleObjects(count, handles, TRUE, INFINITE)) {
+	case WAIT_OBJECT_0:
+		break;
+	case WAIT_FAILED:
+		log_system_error(L"Failed to wait for threads termination due to: ");
+		result = result_error;
+		break;
+	default:
+		log_error(L"Failed to wait for threads termination due to strange reason");
+		result = result_error;
 	}
+
 	for (i = 0; i < count; ++i)
-		CloseHandle( tids[i] );
-
-	free( tids );
-	free( carry );
+		CloseHandle(handles[i]);
 
+	free(handles);
+	handles = NULL;
+	free(carry);
+	carry = NULL;
 	return result;
 }
 
-void single_thread_launcher(XIMC_RETTYPE(XIMC_CALLCONV *func)(void*), void *arg)
+/* Win32 implementation of fork/join with timeout */
+result_t fork_join_with_timeout(fork_join_thread_function_t function, int count, void* args, size_t arg_element_size, int timeout_ms, mutex_t* ext_mutex)
 {
-	if (_beginthreadex(NULL, 0, func, arg, 0, NULL) == 0)
-		log_system_error(L"Failed to create a crt thread due to: ");
-}
-
-/* win32 implementation of fork/join with timeout */
-void fork_join_with_timeout(fork_join_thread_function_t function, int count, void* args, size_t arg_element_size, int timeout_ms, net_enum_t* net_enum)
-{
-	HANDLE* tids;
+	result_t result = result_ok;
+	fork_join_carry_t* carry = (fork_join_carry_t*)malloc(count * sizeof(fork_join_carry_t));
+	HANDLE* handles = (HANDLE*)malloc(count * sizeof(HANDLE));
+	
+	/* Launch and join */
 	int i;
-	fork_join_carry_t* carry;
-	mutex_t **mutexes;
-
-	tids = (HANDLE*)malloc(count*sizeof(HANDLE));
-	carry = (fork_join_carry_t*)malloc(count*sizeof(fork_join_carry_t));
-	mutexes = (mutex_t**)malloc(count*sizeof(mutex_t*));
-
-	/* launch and join */
-	for (i = 0; i < count; ++i)
-	{
+	for (i = 0; i < count; ++i) {
 		carry[i].function = function;
-		carry[i].arg = (byte*)args + i*arg_element_size;
-		mutexes[i] = mutex_init(i); // the nonce is unused on windows only
-		tids[i] = (HANDLE)_beginthreadex(NULL, 0, check_thread_wrapper_win32, &carry[i], 0, NULL);
-		if (tids[i] == 0)
-		{
-			log_system_error(L"Failed to create a crt thread due to: ");
+		carry[i].arg = (byte*)args + i * arg_element_size;
+		handles[i] = (HANDLE)_beginthreadex(NULL, 0, check_thread_wrapper_win32, &carry[i], 0, NULL);
+		if (handles[i] == 0) {
+			result = result_error;
+			log_system_error(L"Failed to create a thread: ");
 		}
 	}
-	/* Wait for timeout and get data from those who returned */
-	switch (WaitForMultipleObjects(count, tids, TRUE, timeout_ms))
-	{
+
+	/* Wait for timeout */
+	switch (WaitForMultipleObjects(count, handles, TRUE, timeout_ms)) {
 	case WAIT_TIMEOUT:
-		log_info(L"Timed out waiting for all network enumeration threads to complete");
+		log_info(L"Timed out waiting for threads to complete");
 		break;
 	case WAIT_OBJECT_0:
 		break;
 	case WAIT_FAILED:
 		log_system_error(L"Failed to wait for threads termination due to: ");
+		result = result_error;
 		break;
 	default:
 		log_error(L"Failed to wait for threads termination due to strange reason");
-	}
-
-	// Lock each personal mutex and copy thread data
-	for (i = 0; i < count; ++i)
-	{
-		mutex_lock(mutexes[i]);
-		netthread_state_t state = *(netthread_state_t*)(carry[i].arg);
-		if (state.status) {
-			net_enum->pbufs[i] = state.pbuf;
-			net_enum->device_count[i] = state.devices_found;
-		}
-		mutex_unlock(mutexes[i]);
+		result = result_error;
 	}
 
 	// Unlock the external mutex
-	mutex_unlock(net_enum->mutex);
-	// After this we can't touch our parameter pointers (net_enum), since they might be already invalid
-
-	/* Wait for infinity to clean up after remaining threads */
-	switch (WaitForMultipleObjects(count, tids, TRUE, INFINITE))
-	{
-	case WAIT_OBJECT_0:
-		break;
-	case WAIT_FAILED:
-		log_system_error(L"Failed to wait for threads termination due to: ");
-		break;
-	default:
-		log_error(L"Failed to wait for threads termination due to strange reason");
+	if (ext_mutex) {
+		mutex_unlock(ext_mutex);
 	}
 
-	for (i = 0; i < count; ++i) {
-		CloseHandle(tids[i]);
-		mutex_close(mutexes[i]);
-	}
+	for (i = 0; i < count; ++i)
+		CloseHandle(handles[i]);
 
-	free(tids);
+	free(handles);
+	handles = NULL;
 	free(carry);
-	free(mutexes);
+	carry = NULL;
+	return result;
 }
 
-void fork_join_2_threads(fork_join_thread_function_t function1, void* args1, int condition1, fork_join_thread_function_t function2, void* args2, int condition2)
+void fork_join_2_threads(fork_join_thread_function_t function_1, void* args_1, fork_join_thread_function_t function_2, void* args_2)
 {
-    HANDLE handles[2];
-    int i, count_launched;
-    fork_join_carry_t* carry;
+	fork_join_carry_t* carry = (fork_join_carry_t*)malloc(2 * sizeof(fork_join_carry_t));
+	HANDLE handles[2];
+    int count_launched = 0;
     
-    count_launched = 0;
-    carry = (fork_join_carry_t*)malloc(2*sizeof(fork_join_carry_t));
-    if (condition1)
-    {
-        carry[0].function = function1;
-        carry[0].arg = (byte*)args1;
-        handles[0] = (HANDLE)_beginthreadex(NULL, 0, check_thread_wrapper_win32, &carry[0], 0, NULL);
-        if (handles[0] == 0)
-        {
-            log_system_error(L"Failed to create a luanch_sheck_threads thread due to: ");
-        }
-        else
-            count_launched++;
-
+	carry[0].function = function_1;
+    carry[0].arg = (byte*)args_1;
+    handles[0] = (HANDLE)_beginthreadex(NULL, 0, check_thread_wrapper_win32, &carry[0], 0, NULL);
+    if (handles[0] == 0) {
+        log_system_error(L"Failed to create thread for searching using SSDP: ");
     }
-    if (condition2)
-    {
-        carry[count_launched].function = function2;
-        carry[count_launched].arg = (byte*)args2;
-        handles[count_launched] = (HANDLE)_beginthreadex(NULL, 0, check_thread_wrapper_win32, &carry[count_launched], 0, NULL);
-        if (handles[count_launched] == 0)
-        {
-             log_system_error(L"Failed to create a single_wrapper thread due to: ");
-        }
-        else
-            count_launched++;
+	else {
+		count_launched++;
+	}
+    
+    carry[count_launched].function = function_2;
+    carry[count_launched].arg = (byte*)args_2;
+    handles[count_launched] = (HANDLE)_beginthreadex(NULL, 0, check_thread_wrapper_win32, &carry[count_launched], 0, NULL);
+    if (handles[count_launched] == 0) {
+		log_system_error(L"Failed to create stream for searching using xinet: ");
     }
+	else {
+		count_launched++;
+	}
 
     /* Join threads or say there are no devices at all */
     if (count_launched)
     {
-
         switch (WaitForMultipleObjects(count_launched, handles, TRUE, INFINITE))
         {
         case WAIT_OBJECT_0:
@@ -329,117 +276,113 @@ void fork_join_2_threads(fork_join_thread_function_t function1, void* args1, int
         }
     }
 
+	int i;
     for (i = 0; i < count_launched; ++i)
         CloseHandle(handles[i]);
+
     free(carry);
+	carry = NULL;
 }
 
+void single_thread_launcher(XIMC_RETTYPE(XIMC_CALLCONV *func)(void*), void* arg)
+{
+	if (_beginthreadex(NULL, 0, func, arg, 0, NULL) == 0) {
+		log_system_error(L"Failed to create a thread: ");
+	}
+}
 
 unsigned long long get_thread_id()
 {
 	return (unsigned long long)GetCurrentThreadId();
 }
 
+
 /*
  * Device enumeration support
  */
 
 bool is_device_name_COM(const char* name)
 {
-	const char *prefix;
+	const char* prefix;
 	// COM3
 	prefix = "COM";
-	if (!portable_strncasecmp( name, prefix, strlen( prefix ) ) &&
-			is_numeric( name + strlen(prefix) ))
+	if (!portable_strncasecmp(name, prefix, strlen(prefix)) && is_numeric(name + strlen(prefix)))
 		return true;
+
 	// \\.\COM10
 	prefix = "\\\\.\\COM";
-	if (!portable_strncasecmp( name, prefix, strlen( prefix ) ) &&
-			is_numeric( name + strlen(prefix) ))
+	if (!portable_strncasecmp(name, prefix, strlen(prefix)) && is_numeric(name + strlen(prefix)))
 		return true;
+
 	return false;
 }
 
-bool is_device_name_ok (char* name, char* description, int flags)
+bool is_device_name_ok(char* name, char* description, int flags)
 {
 	const char* ximcDeviceSignature = "XIMC Motor Controller";
-    const char*mdriveDeviceSignature = "mDrive Motor Controller";
-	if (is_device_name_COM( name ))
-	{
-		return (flags & ENUMERATE_ALL_COM)
-			? true
-            : (strstr(description, ximcDeviceSignature) != NULL || strstr(description, mdriveDeviceSignature) != NULL);
-	}
-	else
-		return false;
+    const char* mdriveDeviceSignature = "mDrive Motor Controller";
+	if (is_device_name_COM(name))
+		return (flags & ENUMERATE_ALL_COM) ? true : (strstr(description, ximcDeviceSignature) != NULL || strstr(description, mdriveDeviceSignature) != NULL);
+	
+	return false;
 }
 
-bool is_same_device (const char* name1, const char* name2)
+bool is_same_device(const char* name_1, const char* name_2)
 {
-	return !strcmp( name1, name2 );
+	return !strcmp(name_1, name_2);
 }
 
-result_t enumerate_devices_directory (enumerate_devices_directory_callback_t callback, void* arg, int flags)
+result_t discover_local_devices(enumerate_devices_directory_callback_t callback, void* arg, int flags)
 {
-	int nIndex;
 	SP_DEVINFO_DATA devInfo;
 	char pszValue[256];
 	char friendlyName[512];
 	char fullName[256];
-	DWORD dwSize;
-	DWORD dwType;
 	GUID guid = GUID_DEVINTERFACE_COMPORT;
 	HKEY hDeviceKey;
-	HDEVINFO hDevInfoSet;
 
 	/* Open a dir */
-	hDevInfoSet = SetupDiGetClassDevs( &guid, NULL, NULL, DIGCF_PRESENT | DIGCF_ALLCLASSES );
-
-	if (hDevInfoSet == INVALID_HANDLE_VALUE)
-	{
-		log_system_error( L"Can't open class due to: " );
+	HDEVINFO hDevInfoSet = SetupDiGetClassDevs(&guid, NULL, NULL, DIGCF_PRESENT | DIGCF_ALLCLASSES);
+	if (hDevInfoSet == INVALID_HANDLE_VALUE) {
+		log_system_error(L"Can't open class due to: ");
 		return result_error;
 	}
 
-	for (nIndex = 0;; ++nIndex)
-	{
-		//Enumerate the current device
+	int nIndex;
+	for (nIndex = 0;; ++nIndex) {
+		// Enumerate the current device
 		devInfo.cbSize = sizeof(SP_DEVINFO_DATA);
 		if (!SetupDiEnumDeviceInfo(hDevInfoSet, nIndex, &devInfo))
 			break;
 
-		//Get the registry key which stores the ports settings
+		// Get the registry key which stores the ports settings
 		hDeviceKey = SetupDiOpenDevRegKey(hDevInfoSet, &devInfo, DICS_FLAG_GLOBAL, 0, DIREG_DEV, KEY_QUERY_VALUE);
-		if (hDeviceKey != INVALID_HANDLE_VALUE)
-		{
-			dwSize = sizeof(pszValue);
-			dwType = 0;
-			if (RegQueryValueExA(hDeviceKey, "PortName", NULL, &dwType, (LPBYTE)pszValue, &dwSize) == ERROR_SUCCESS &&
-				dwType == REG_SZ)
-			{
-				if (!SetupDiGetDeviceRegistryPropertyA(hDevInfoSet, &devInfo, SPDRP_FRIENDLYNAME, NULL,
-							(BYTE*)friendlyName, sizeof(friendlyName), NULL))
-					log_warning( L"Cannot get friendly name for port %hs", pszValue );
-				friendlyName[sizeof(friendlyName)-1] = 0;
-				log_debug( L"Friendly name: %hs", friendlyName );
+		if (hDeviceKey != INVALID_HANDLE_VALUE) {
+			DWORD dwSize = sizeof(pszValue);
+			DWORD dwType = 0;
+			if (RegQueryValueExA(hDeviceKey, "PortName", NULL, &dwType, (LPBYTE)pszValue, &dwSize) == ERROR_SUCCESS && dwType == REG_SZ) {
+				if (!SetupDiGetDeviceRegistryPropertyA(hDevInfoSet, &devInfo, SPDRP_FRIENDLYNAME, NULL, (BYTE*)friendlyName, sizeof(friendlyName), NULL))
+					log_warning(L"Cannot get friendly name for port '%hs'", pszValue);
 
-				if (is_device_name_ok( pszValue, friendlyName, flags ))
-				{
-					portable_snprintf( fullName, sizeof(fullName), "\\\\.\\%s", pszValue );
+				friendlyName[sizeof(friendlyName) - 1] = 0;
+				log_debug(L"Friendly name: '%hs'", friendlyName);
+
+				if (is_device_name_ok(pszValue, friendlyName, flags)) {
+					portable_snprintf(fullName, sizeof(fullName), "\\\\.\\%s", pszValue);
 					fullName[sizeof(fullName)-1] = 0;
-					callback( fullName, arg );
+					callback(fullName, arg);
 				}
 				else
-					log_debug( L"Skip port %hs", pszValue );
+					log_debug(L"Skip port '%hs'", pszValue);
 			}
 			RegCloseKey(hDeviceKey);
 		}
 	}
 	SetupDiDestroyDeviceInfoList(hDevInfoSet);
-
 	return result_ok;
 }
 
+
 /*
  * Error handling
  */
@@ -451,32 +394,34 @@ int is_error_nodevice(unsigned int errcode)
 		errcode == ERROR_FILE_NOT_FOUND || errcode == ERROR_DEVICE_NOT_CONNECTED;
 }
 
-void set_error_nodevice ()
+void set_error_nodevice()
 {
 	SetLastError(ERROR_DEVICE_NOT_CONNECTED);
 }
 
-unsigned int get_system_error_code ()
+unsigned int get_system_error_code()
 {
 	return GetLastError();
 }
 
-wchar_t* get_system_error_str (int code)
+wchar_t* get_system_error_str(int code)
 {
 	wchar_t* result;
 	if (FormatMessageW( FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM, NULL,
 			code, MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), (LPWSTR) &result, 0, NULL ) == 0)
 		return NULL;
-	wcsrstrip( result, L"\r\n" );
+
+	wcsrstrip(result, L"\r\n");
 	return result;
 }
 
-void free_system_error_str (wchar_t* str)
+void free_system_error_str(wchar_t* str)
 {
 	if (str)
-		LocalFree( str );
+		LocalFree(str);
 }
 
+
 /*
  * Misc
  */
@@ -611,12 +556,12 @@ int set_default_bindy_key()
 #endif
 }
 
+
 /*
  * Lock support
  */
 
-/* We must have conditional here because vcproj can't select
- * files by macro */
+/* We must have conditional here because vcproj can't select files by macro */
 
 #ifdef HAVE_LOCKS
 
@@ -627,65 +572,62 @@ struct mutex_t
 
 mutex_t* mutex_init(unsigned int nonce)
 {
-	mutex_t* mutex = malloc( sizeof(mutex_t) );
+	mutex_t* mutex = malloc(sizeof(mutex_t));
 	XIMC_UNUSED(nonce);
-	if (!mutex)
-	{
-		log_system_error( L"can't create semaphore" );
+	if (!mutex) {
+		log_system_error(L"Failed to allocate memory for 'mutex_t' structure: ");
 		return NULL;
 	}
-	mutex->impl = CreateSemaphore( NULL, 1, 1, NULL );
-	if (!mutex->impl)
-	{
-		free( mutex );
-		log_system_error( L"can't create semaphore" );
+
+	mutex->impl = CreateSemaphore(NULL, 1, 1, NULL);
+	if (!mutex->impl) {
+		free(mutex);
+		mutex = NULL;
+		log_system_error(L"Failed to create semaphore: ");
 		return NULL;
 	}
-	log_debug( L"semaphore %ld inited", mutex->impl );
+
+	log_debug(L"Semaphore %ld inited", mutex->impl);
 	return mutex;
 }
 
 void mutex_close(mutex_t* mutex)
 {
-	if (mutex)
-	{
-		if (mutex->impl)
-		{
-			CloseHandle( mutex->impl );
+	if (mutex) {
+		if (mutex->impl) {
+			CloseHandle(mutex->impl);
 		}
-		log_debug( L"semaphore %ld closed", mutex->impl );
-		free( mutex );
+		log_debug(L"Semaphore %ld closed", mutex->impl);
+		free(mutex);
+		mutex = NULL;
 	}
 }
 
 void mutex_lock(mutex_t* mutex)
 {
-	if (!mutex || !mutex->impl)
-	{
-		log_error( L"no semaphore specified" );
+	if (!mutex || !mutex->impl) {
+		log_error(L"No semaphore specified");
 		return;
 	}
-	switch (WaitForSingleObject( mutex->impl, INFINITE ))
-	{
-		case WAIT_OBJECT_0:
-			// ok
-			break;
-		default:
-			log_system_error( L"can't wait on semaphore %ld due to ", mutex->impl );
+
+	switch (WaitForSingleObject(mutex->impl, INFINITE)) {
+	case WAIT_OBJECT_0:
+		// ok
+		break;
+	default:
+		log_system_error(L"Failed to wait on semaphore %ld due to: ", mutex->impl);
 	}
 }
 
 void mutex_unlock(mutex_t* mutex)
 {
-	if (!mutex || !mutex->impl)
-	{
-		log_error( L"no semaphore specified" );
+	if (!mutex || !mutex->impl) {
+		log_error(L"No semaphore specified");
 		return;
 	}
-	if (!ReleaseSemaphore( mutex->impl, 1, NULL ))
-		log_system_error( L"can't post on semaphore %ld due to ", mutex->impl );
+
+	if (!ReleaseSemaphore(mutex->impl, 1, NULL))
+		log_system_error(L"Failed to release semaphore %ld due to: ", mutex->impl);
 }
 
 #endif
-
-// vim: syntax=c tabstop=4 shiftwidth=4
