@@ -1,4 +1,4 @@
-def set_profile_8MR190_90_4247_MEn1(lib, id):
+def set_profile_8MR174_11_28_MEn1(lib, id):
     worst_result = Result.Ok
     result = Result.Ok
 
@@ -10,7 +10,7 @@ def set_profile_8MR190_90_4247_MEn1(lib, id):
         FEEDBACK_NONE = 5
         FEEDBACK_EMF = 4
         FEEDBACK_ENCODER = 1
-    feedback_settings.FeedbackType = FeedbackType_.FEEDBACK_NONE
+    feedback_settings.FeedbackType = FeedbackType_.FEEDBACK_EMF
     class FeedbackFlags_:
         FEEDBACK_ENC_TYPE_BITS = 192
         FEEDBACK_ENC_TYPE_DIFFERENTIAL = 128
@@ -27,12 +27,12 @@ def set_profile_8MR190_90_4247_MEn1(lib, id):
 
     home_settings = home_settings_t()
 
-    home_settings.FastHome = 100
+    home_settings.FastHome = 1000
     home_settings.uFastHome = 0
     home_settings.SlowHome = 10
     home_settings.uSlowHome = 0
-    home_settings.HomeDelta = 3000
-    home_settings.uHomeDelta = 0
+    home_settings.HomeDelta = 1091
+    home_settings.uHomeDelta = 6
     class HomeFlags_:
         HOME_USE_FAST = 256
         HOME_STOP_SECOND_BITS = 192
@@ -56,11 +56,11 @@ def set_profile_8MR190_90_4247_MEn1(lib, id):
 
     move_settings = move_settings_t()
 
-    move_settings.Speed = 1000
+    move_settings.Speed = 2000
     move_settings.uSpeed = 0
     move_settings.Accel = 2000
-    move_settings.Decel = 4000
-    move_settings.AntiplaySpeed = 1000
+    move_settings.Decel = 5000
+    move_settings.AntiplaySpeed = 2000
     move_settings.uAntiplaySpeed = 0
     class MoveFlags_:
         RPM_DIV_1000 = 1
@@ -73,9 +73,9 @@ def set_profile_8MR190_90_4247_MEn1(lib, id):
 
     engine_settings = engine_settings_t()
 
-    engine_settings.NomVoltage = 1
-    engine_settings.NomCurrent = 1200
-    engine_settings.NomSpeed = 2400
+    engine_settings.NomVoltage = 360
+    engine_settings.NomCurrent = 670
+    engine_settings.NomSpeed = 5000
     engine_settings.uNomSpeed = 0
     class EngineFlags_:
         ENGINE_LIMIT_RPM = 128
@@ -86,8 +86,8 @@ def set_profile_8MR190_90_4247_MEn1(lib, id):
         ENGINE_MAX_SPEED = 4
         ENGINE_CURRENT_AS_RMS = 2
         ENGINE_REVERSE = 1
-    engine_settings.EngineFlags = EngineFlags_.ENGINE_LIMIT_RPM | EngineFlags_.ENGINE_ACCEL_ON | EngineFlags_.ENGINE_REVERSE
-    engine_settings.Antiplay = 575
+    engine_settings.EngineFlags = EngineFlags_.ENGINE_LIMIT_RPM | EngineFlags_.ENGINE_ACCEL_ON
+    engine_settings.Antiplay = 1800
     class MicrostepMode_:
         MICROSTEP_MODE_FRAC_256 = 9
         MICROSTEP_MODE_FRAC_128 = 8
@@ -137,7 +137,7 @@ def set_profile_8MR190_90_4247_MEn1(lib, id):
         POWER_SMOOTH_CURRENT = 4
         POWER_OFF_ENABLED = 2
         POWER_REDUCT_ENABLED = 1
-    power_settings.PowerFlags = PowerFlags_.POWER_SMOOTH_CURRENT | PowerFlags_.POWER_OFF_ENABLED | PowerFlags_.POWER_REDUCT_ENABLED
+    power_settings.PowerFlags = PowerFlags_.POWER_SMOOTH_CURRENT | PowerFlags_.POWER_REDUCT_ENABLED
     result = lib.set_power_settings(id, byref(power_settings))
 
     if result != Result.Ok:
@@ -182,9 +182,9 @@ def set_profile_8MR190_90_4247_MEn1(lib, id):
         ENDER_SW1_ACTIVE_LOW = 2
         ENDER_SWAP = 1
     edges_settings.EnderFlags = EnderFlags_.ENDER_SW2_ACTIVE_LOW | EnderFlags_.ENDER_SW1_ACTIVE_LOW
-    edges_settings.LeftBorder = -2400
+    edges_settings.LeftBorder = -491
     edges_settings.uLeftBorder = 0
-    edges_settings.RightBorder = 20400
+    edges_settings.RightBorder = 22309
     edges_settings.uRightBorder = 0
     result = lib.set_edges_settings(id, byref(edges_settings))
 
@@ -197,8 +197,8 @@ def set_profile_8MR190_90_4247_MEn1(lib, id):
     pid_settings.KpU = 0
     pid_settings.KiU = 0
     pid_settings.KdU = 0
-    pid_settings.Kpf = 0.003599999938160181
-    pid_settings.Kif = 0.03799999877810478
+    pid_settings.Kpf = 0.006000000052154064
+    pid_settings.Kif = 0.05000000074505806
     pid_settings.Kdf = 2.8000000384054147e-05
     result = lib.set_pid_settings(id, byref(pid_settings))
 
@@ -290,9 +290,9 @@ def set_profile_8MR190_90_4247_MEn1(lib, id):
 
     control_settings = control_settings_t()
 
-    control_settings.MaxSpeed[0] = 100
-    control_settings.MaxSpeed[1] = 1000
-    control_settings.MaxSpeed[2] = 0
+    control_settings.MaxSpeed[0] = 20
+    control_settings.MaxSpeed[1] = 200
+    control_settings.MaxSpeed[2] = 2000
     control_settings.MaxSpeed[3] = 0
     control_settings.MaxSpeed[4] = 0
     control_settings.MaxSpeed[5] = 0
@@ -361,7 +361,7 @@ def set_profile_8MR190_90_4247_MEn1(lib, id):
         CTP_ALARM_ON_ERROR = 4
         CTP_BASE = 2
         CTP_ENABLED = 1
-    ctp_settings.CTPFlags = CTPFlags_.CTP_ERROR_CORRECTION | CTPFlags_.CTP_ENABLED
+    ctp_settings.CTPFlags = CTPFlags_.CTP_ERROR_CORRECTION
     result = lib.set_ctp_settings(id, byref(ctp_settings))
 
     if result != Result.Ok:
@@ -400,9 +400,9 @@ def set_profile_8MR190_90_4247_MEn1(lib, id):
 
     emf_settings = emf_settings_t()
 
-    emf_settings.L = 0
-    emf_settings.R = 0
-    emf_settings.Km = 0
+    emf_settings.L = 0.005400000140070915
+    emf_settings.R = 7.400000095367432
+    emf_settings.Km = 0.0024999999441206455
     class BackEMFFlags_:
         BACK_EMF_KM_AUTO = 4
         BACK_EMF_RESISTANCE_AUTO = 2
@@ -446,7 +446,7 @@ def set_profile_8MR190_90_4247_MEn1(lib, id):
     stage_information = stage_information_t()
 
     stage_information.Manufacturer = bytes([0, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
-    stage_information.PartNumber = bytes([56, 77, 82, 49, 57, 48, 45, 57, 48, 45, 52, 50, 52, 55, 45, 77, 69, 110, 49, 0, 45, 69, 65, 83])
+    stage_information.PartNumber = bytes([56, 77, 82, 49, 55, 52, 45, 49, 49, 45, 50, 56, 45, 77, 69, 110, 49, 0, 48, 68, 45, 69, 65, 83])
     result = lib.set_stage_information(id, byref(stage_information))
 
     if result != Result.Ok:
@@ -457,7 +457,7 @@ def set_profile_8MR190_90_4247_MEn1(lib, id):
 
     stage_settings.LeadScrewPitch = 3
     stage_settings.Units = bytes([0, 101, 103, 114, 101, 101, 0, 0])
-    stage_settings.MaxSpeed = 36
+    stage_settings.MaxSpeed = 75
     stage_settings.TravelRange = 360
     stage_settings.SupplyVoltageMin = 0
     stage_settings.SupplyVoltageMax = 0
@@ -472,7 +472,7 @@ def set_profile_8MR190_90_4247_MEn1(lib, id):
 
     motor_information = motor_information_t()
 
-    motor_information.Manufacturer = bytes([0, 111, 116, 105, 111, 110, 32, 67, 111, 110, 116, 114, 111, 108, 32, 80])
+    motor_information.Manufacturer = bytes([0, 97, 120, 111, 110, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
     motor_information.PartNumber = bytes([0, 67, 45, 105, 45, 52, 48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
     result = lib.set_motor_information(id, byref(motor_information))
 
